@@ -15,11 +15,13 @@ Controlling playback.
 module Network.MPD.Commands.PlaybackControl
     ( next
     , pause
+    , toggle
     , play
     , playId
     , previous
     , seek
     , seekId
+    , seekCur
     , stop
     ) where
 
@@ -32,10 +34,16 @@ import           Network.MPD.Core
 next :: MonadMPD m => m ()
 next = A.runCommand A.next
 
--- | Pause playing.
+-- | Pauses playback on True, resumes on False.
 pause :: MonadMPD m => Bool -> m ()
 pause = A.runCommand . A.pause
 
+-- | Toggles play\/pause. Plays if stopped.
+--
+-- @since 0.10.0.0
+toggle :: MonadMPD m => m ()
+toggle = A.runCommand A.toggle
+
 -- | Begin\/continue playing.
 play :: MonadMPD m => Maybe Position -> m ()
 play = A.runCommand . A.play
@@ -56,6 +64,13 @@ seek pos = A.runCommand . A.seek pos
 seekId :: MonadMPD m => Id -> FractionalSeconds -> m ()
 seekId id' = A.runCommand . A.seekId id'
 
+-- | Seek to some point in the current song. Absolute time for True in
+-- the frist argument, relative time for False.
+--
+-- @since 0.9.2.0
+seekCur :: MonadMPD m => Bool -> FractionalSeconds -> m ()
+seekCur bool = A.runCommand . A.seekCur bool
+
 -- | Stop playing.
 stop :: MonadMPD m => m ()
 stop = A.runCommand A.stop
